=== modified file '.bzrignore'
--- .bzrignore	2010-10-13 00:26:41 +0000
+++ .bzrignore	2012-08-07 06:32:51 +0000
@@ -25,6 +25,7 @@
 # setup.py working directory
 ./build
 ./build-win32
+./bzrlib/locale
 # Editor temporary/working/backup files
 *$
 .*.sw[nop]

=== modified file 'INSTALL'
--- INSTALL	2010-06-02 05:03:31 +0000
+++ INSTALL	2012-08-30 20:36:18 +0000
@@ -4,9 +4,7 @@
 Dependencies
 ------------
 
-bzr requires Python2.4 and cElementTree:
-
-  http://effbot.org/zone/element-index.htm
+bzr requires Python 2.6 or newer.
 
 If you wish to access branches over sftp, you will need paramiko and
 pycrypto:

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2012-07-31 08:46:40 +0000
+++ bzrlib/builtins.py	2012-09-05 20:22:17 +0000
@@ -5141,6 +5141,7 @@
             Option('strict',
                    help='Produce a strict-format testament.')]
     takes_args = ['branch?']
+    encoding_type = 'exact'
     @display_command
     def run(self, branch=u'.', revision=None, long=False, strict=False):
         from bzrlib.testament import Testament, StrictTestament
@@ -5159,9 +5160,9 @@
             rev_id = revision[0].as_revision_id(b)
         t = testament_class.from_revision(b.repository, rev_id)
         if long:
-            sys.stdout.writelines(t.as_text_lines())
+            self.outf.writelines(t.as_text_lines())
         else:
-            sys.stdout.write(t.as_short_text())
+            self.outf.write(t.as_short_text())
 
 
 class cmd_annotate(Command):

=== modified file 'bzrlib/tests/blackbox/test_testament.py'
--- bzrlib/tests/blackbox/test_testament.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/blackbox/test_testament.py	2012-06-08 06:59:50 +0000
@@ -16,8 +16,10 @@
 
 """Blackbox tests for the 'bzr testament' command"""
 
+import re
 
 from bzrlib.tests.test_testament import (
+    osutils,
     REV_1_SHORT,
     REV_1_SHORT_STRICT,
     REV_2_TESTAMENT,
@@ -46,3 +48,12 @@
         self.assertEqualDiff(err, '')
         self.assertEqualDiff(out, REV_1_SHORT_STRICT)
 
+    def test_testament_non_ascii(self):
+        self.wt.commit(u"Non \xe5ssci message")
+        long_out, err = self.run_bzr('testament --long')
+        self.assertEqualDiff(err, '')
+        short_out, err = self.run_bzr('testament')
+        self.assertEqualDiff(err, '')
+        sha1_re = re.compile('sha1: (?P<sha1>[a-f0-9]+)$', re.M)
+        sha1 = sha1_re.search(short_out).group('sha1')
+        self.assertEqual(sha1, osutils.sha_string(long_out))

=== modified file 'doc/developers/code-style.txt'
--- doc/developers/code-style.txt	2011-06-28 21:45:01 +0000
+++ doc/developers/code-style.txt	2012-08-30 21:54:35 +0000
@@ -77,20 +77,11 @@
 Python versions
 ===============
 
-Bazaar supports Python from 2.4 through 2.6, and in the future we want to
-support Python 2.7 and 3.0.  Avoid using language features added in 2.5,
-2.6 or 2.7, or features deprecated in Python 3.0.  (You can check v3
+Bazaar supports Python from 2.6 through 2.7, and in the future we want to
+support Python 3.  Avoid using language features added in
+2.7, or features deprecated in Python 3.0.  (You can check v3
 compatibility using the ``-3`` option of Python2.6.)
 
-Specifically:
-
-* Don't use the ``with`` statement.
-
-* Don't ``from . import``.
-
-* Don't use ``try/except/finally``, which is not supported in Python2.4,
-  use separate nested ``try/except`` and ``try/finally`` blocks.
-
 
 hasattr and getattr
 ===================

=== modified file 'doc/en/admin-guide/introduction.txt'
--- doc/en/admin-guide/introduction.txt	2010-06-02 05:03:31 +0000
+++ doc/en/admin-guide/introduction.txt	2012-08-30 21:21:38 +0000
@@ -31,13 +31,12 @@
 environments.  For the purposes of this document, we will consider Mac OS X as
 a type of Unix.
 
-In general, Bazaar requires only Python_ 2.4 or greater and the cElementTree_
-package (included in Python 2.5 and later) to run.  If you would *optionally*
+In general, Bazaar requires only Python_ 2.6 or greater to run.
+If you would *optionally*
 like to be able to access branches using SFTP, you need `paramiko and
 pycrypto`_.
 
 .. _Python: http://www.python.org/
-.. _cElementTree: http://effbot.org/zone/element-index.htm
 .. _paramiko and pycrypto: http://www.lag.net/paramiko/
 
 For maximum performance, Bazaar can make use of compiled versions of some

=== modified file 'doc/en/release-notes/bzr-2.4.txt'
--- doc/en/release-notes/bzr-2.4.txt	2012-06-18 11:43:07 +0000
+++ doc/en/release-notes/bzr-2.4.txt	2012-09-05 20:22:17 +0000
@@ -55,6 +55,10 @@
 * Prevent a traceback being printed to stderr when logging has problems and
   accept utf-8 byte string without breaking. (Martin Packman, #714449)
 
+* Use ``encoding_type='exact'`` for ``bzr testament`` so that on Windows
+  the sha hash of the long testament matches the sha hash in the short
+  form. (John Arbash Meinel, #1010339)
+
 * _Win32Stat object provides members st_uid and st_gid, those are present
   in Python's os.stat object. These members required for external tools like
   bzr-git and dulwich. (Alexander Belchenko, #967060)

